@@ -1,7 +1,7 @@
 """
 Core Hyperpython API
 """
-__version__ = '0.3.0'
+__version__ = '1.0.1'
 __author__ = 'Fábio Macêdo Mendes'
 
 # Ugly hack to make it possible to store __version__ directly on __init__.py
@@ -23,7 +23,7 @@ try:
         frame, frameset, noframes, strike, tt
     )
     from .utils import escape, unescape, safe, sanitize
-    from .fragment import fragment
+    from .fragment import fragment, FragmentNotFound
     from .helpers import classes
 except ImportError as exc:
     print('Caught exception:', exc)
