@@ -1,6 +1,6 @@
 from .data import html_map, html_list, html_table, wrap
 from .hyperlinks import a_or_span, a_or_p, hyperlink, breadcrumbs, url
-from .icons import icon, fa_icon, fab_icon
+from .icons import icon, fa_icon
 from .text import markdown
 from .page import meta_properties, meta_headers, meta_og, meta_values, \
     stylesheets, scripts, favicons, google_analytics, Head
