@@ -7,7 +7,7 @@ from ..tags import ul, ol, li, dl, dd, dt, table, thead, tbody, tr, td, th
 
 
 @html.register(Iterable)
-def html_list(data, ordered=False, role=None, **kwargs):
+def html_list(data, role=None, ordered=False, **kwargs):
     """
     Convert a Python iterable into an HTML list element.
 
@@ -23,7 +23,7 @@ def html_list(data, ordered=False, role=None, **kwargs):
 
     Examples:
         >>> doc = html_list([1, 2, 3])
-        >>> pprint(doc)
+        >>> print(doc.pretty())
         <ul>
             <li>1</li>
             <li>2</li>
@@ -36,16 +36,17 @@ def html_list(data, ordered=False, role=None, **kwargs):
 
 
 @html.register(Mapping)
-def html_map(data, role=None, **kwargs):
+def html_map(data, role=None, key_role=None, **kwargs):
     """
-    Renders mapping as a description list.
+    Renders mapping as a description list using dt as keys and dt as values.
 
     Args:
         data:
             Sequence data.
-        role, strict, ctx:
-            Arguments to pass to render() to transform each element in the
-            sequence.
+        role:
+            Role passed to the dd (values) elements of the description list.
+        key_role:
+            Role passed to the dt (keys) elements of the description list.
 
         Additional keyword arguments are passed to the root element.
 
@@ -62,12 +63,12 @@ def html_map(data, role=None, **kwargs):
     body = []
     items = getattr(data, 'items', lambda: data)
     for k, v in items():
-        body.append(dt(html(k, role=role)))
+        body.append(dt(html(k, role=key_role)))
         body.append(dd(html(v, role=role)))
     return dl(body, **kwargs)
 
 
-def html_table(data, columns=None, role=None, **kwargs):
+def html_table(data, role=None, columns=None, **kwargs):
     """
     Convert 2D matrix-like data to an HTML table.
 
@@ -76,9 +77,8 @@ def html_table(data, columns=None, role=None, **kwargs):
             Sequence data.
         columns:
             A list of column names to be added as <thead>.
-        role, strict, ctx:
-            Arguments to pass to render() to transform each element in the
-            sequence.
+        role:
+            Role used to render elements of the table.
 
         Additional keyword arguments are passed to the root element.
 
