@@ -1,8 +1,8 @@
 import collections
 
-from ..html import html
 from ..core import Element
-from ..tags import a, p, span, h
+from ..html import html
+from ..tags import a, p, span, h, ul, li
 from ..utils import escape, lazy_singledispatch
 from ..utils.role_dispatch import role_singledispatch
 
@@ -52,7 +52,9 @@ def hyperlink(obj, href=None, **attrs) -> Element:
             It must define a get_absolute_url() method. This function uses
             this result as the href field and str(model) as its content.
 
-            >>> hyperlink(User(first_name='Joe', username='joe123'))
+            >>> from django.contrib.auth import get_user_model
+            >>> user_model = get_user_model()
+            >>> hyperlink(user_model(first_name='Joe', username='joe123'))
             <a href="/users/joe123">Joe</a>
 
 
@@ -65,8 +67,9 @@ def hyperlink(obj, href=None, **attrs) -> Element:
 
     See Also:
 
-        :func:`pyml.helpers.attrs`: See this function for an exact explanation
-            of how keyword arguments are translated into HTML attributes.
+        :func:`hyperpython.helpers.attrs`: See this function for an exact
+            explanation of how keyword arguments are translated into HTML
+            attributes.
     """
 
     data = html(obj)
@@ -127,8 +130,8 @@ def split_link(name):
     return name, None
 
 
-def breadcrumbs(x, *paths, level=0, **kwargs):
+def breadcrumbs(links, class_='breadcrumbs'):
     """
-    Component thta Receives a list of links and return a breadcrumbs element.
+    Component that Receives a list of links and return a breadcrumbs element.
     """
-    raise NotImplementedError
+    return ul(class_=class_, children=[li(hyperlink(x) for x in links)])
